@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2021 Pier Carlo Chiodi
+# Copyright (C) 2017-2022 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -576,5 +576,56 @@ class OpenBGPD72PortableInstance(OpenBGPDPortableInstance):
     BGP_SPEAKER_VERSION = "7.2"
     TARGET_VERSION = "7.2"
 
-OpenBGPDPortablePreviousInstance = OpenBGPD71PortableInstance
-OpenBGPDPortableLatestInstance = OpenBGPD72PortableInstance
+
+class OpenBGPD73PortableInstance(OpenBGPDPortableInstance):
+
+    DOCKER_IMAGE = "pierky/openbgpd:7.3"
+
+    TAG = "openbgpd73p"
+
+    BGP_SPEAKER_VERSION = "7.3"
+    TARGET_VERSION = "7.3"
+
+
+class OpenBGPD74PortableInstance(OpenBGPDPortableInstance):
+
+    DOCKER_IMAGE = "pierky/openbgpd:7.4"
+
+    TAG = "openbgpd74p"
+
+    BGP_SPEAKER_VERSION = "7.4"
+    TARGET_VERSION = "7.4"
+
+
+class OpenBGPD75PortableInstance(OpenBGPDPortableInstance):
+
+    DOCKER_IMAGE = "pierky/openbgpd:7.5"
+
+    TAG = "openbgpd75p"
+
+    BGP_SPEAKER_VERSION = "7.5"
+    TARGET_VERSION = "7.5"
+
+
+class OpenBGPD76PortableInstance(OpenBGPDPortableInstance):
+
+    DOCKER_IMAGE = "pierky/openbgpd:7.6"
+
+    TAG = "openbgpd76p"
+
+    BGP_SPEAKER_VERSION = "7.6"
+    TARGET_VERSION = "7.6"
+
+
+class OpenBGPD77PortableInstance(OpenBGPDPortableInstance):
+
+    DOCKER_IMAGE = "pierky/openbgpd:7.7"
+
+    TAG = "openbgpd77p"
+
+    BGP_SPEAKER_VERSION = "7.7"
+    TARGET_VERSION = "7.7"
+
+
+OpenBGPDPortablePreviousInstance = OpenBGPD76PortableInstance
+OpenBGPDPortableLatestInstance = OpenBGPD77PortableInstance
